@@ -13,13 +13,13 @@ GPS::PRN - Package for PRN - Object ID conversions.
 
 =head1 DESCRIPTION
 
-=head3 Object Identification Number (OID)
+=head2 Object Identification Number (OID)
 
 The catalog number assigned to the object by the US Air Force. The numbers are assigned sequentially as objects are cataloged. This is the most common way to search for TLE data on this site.
 
 Object numbers less then 10000 are always aligned to the right, and padded with zeros or spaces to the left.
 
-=head3 Pseudo Randum Numbers (PRNs)
+=head2 Pseudo Randum Numbers (PRNs)
 
 GPS satellites are identified by the receiver by means of PRN-numbers. Real GPS satellites are numbered from 1 – 32. WAAS/EGNOS satellites and other pseudolites higher numbers are assigned. These PRN-numbers of the satellites appear on the satellite view screens of many GPS receivers. For simplification of the satellite network 32 different PRN-numbers are available.
 
@@ -32,7 +32,7 @@ Function naming convention is "format of the return" underscore "format of the p
 
 use strict;
 use vars qw($VERSION);
-$VERSION = sprintf("%d.%02d", q{Revision: 0.02} =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q{Revision: 0.03} =~ /(\d+)\.(\d+)/);
 
 =head1 CONSTRUCTOR
 
@@ -93,51 +93,86 @@ sub oid_prn {
   return $data->{$param};
 }
 
+=head2 listprn
+
+List all known PRNs.
+
+  my @prn=$obj->listprn;
+  my $prn=$obj->listprn;
+
+=cut
+
+sub listprn {
+  my $self=shift();
+  my %list=$self->data;
+  my @list=sort {$a <=> $b} values %list;
+  return wantarray ? @list : \@list;
+}
+
+=head2 listoid
+
+List all known PRNs.
+
+  my @oid=$obj->listoid;
+  my $oid=$obj->listoid;
+
+=cut
+
+sub listoid {
+  my $self=shift();
+  my %list=$self->data;
+  my @list=sort {$a <=> $b} keys %list;
+  return wantarray ? @list : \@list;
+}
+
 =head2 data
 
-OID to PRN hash
+OID to PRN hash reference
+
+  my $data=$self->data;
 
 =cut
 
 sub data {
   my $self=shift();
   unless (defined($self->{'data'})) {
-    $self->{'data'}={
-                     22231 => q{01},
-                     28474 => q{02},
-                     23833 => q{03},
-                     22877 => q{04},
-                     22779 => q{05},
-                     23027 => q{06},
-                     22657 => q{07},
-                     25030 => q{08},
-                     22700 => q{09},
-                     23953 => q{10},
-                     25933 => q{11},
-                     29601 => q{12},
-                     24876 => q{13},
-                     26605 => q{14},
-                     20830 => q{15},
-                     27663 => q{16},
-                     28874 => q{17},
-                     26690 => q{18},
-                     28190 => q{19},
-                     26360 => q{20},
-                     27704 => q{21},
-                     28129 => q{22},
-                     28361 => q{23},
-                     21552 => q{24},
-                     21890 => q{25},
-                     22014 => q{26},
-                     22108 => q{27},
-                     26407 => q{28},
-                     22275 => q{29},
-                     24320 => q{30},
-                     29486 => q{31},
-                     24819 => q{135} #or is this 122?
-                    };
+    my %data=(
+              22231 => q{01},
+              28474 => q{02},
+              23833 => q{03},
+              22877 => q{04},
+              22779 => q{05},
+              23027 => q{06},
+              22657 => q{07},
+              25030 => q{08},
+              22700 => q{09},
+              23953 => q{10},
+              25933 => q{11},
+              29601 => q{12},
+              24876 => q{13},
+              26605 => q{14},
+              20830 => q{15},
+              27663 => q{16},
+              28874 => q{17},
+              26690 => q{18},
+              28190 => q{19},
+              26360 => q{20},
+              27704 => q{21},
+              28129 => q{22},
+              28361 => q{23},
+              21552 => q{24},
+              21890 => q{25},
+              22014 => q{26},
+              22108 => q{27},
+              26407 => q{28},
+              22275 => q{29},
+              24320 => q{30},
+              29486 => q{31},
+              24819 => q{135} #or is this 122?
+             );
+    $self->{'data'}=\%data;
   }
-  return $self->{'data'};
+  return wantarray ? %{$self->{'data'}} : $self->{'data'};
 }
 
 =head2 overload
